@@ -1,11 +1,10 @@
 /**
- * SPDX-FileCopyrightText: 2020 Tobias Fella <fella@posteo.de>
+ * SPDX-FileCopyrightText: 2020 Tobias Fella <tobias.fella@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef AUTHOR_H
-#define AUTHOR_H
+#pragma once
 
 #include <QObject>
 
@@ -30,5 +29,3 @@ private:
     QString m_email;
     QString m_url;
 };
-
-#endif // AUTHOR_H
